require 5.8.0;
use strict;
use ExtUtils::MakeMaker;

my @scripts = ("gpgmail");
my $VERSION_FROM = 'gpgmail';
my ($PACKAGE, $AUTHOR, $PREV_VERSION);

# ɸ⥸塼Υå
my $missing_modules = 0;

print "Checking for Config::IniFiles....";
eval {
    require Config::IniFiles;
    Config::IniFiles->VERSION(2.27);
};
if ($@) {
    print " failed\n";
    $missing_modules++;
    print <<EOT;
$@
The Config::IniFiles module must be installed.

EOT
    sleep(2);  # Don't hurry too much
} else {
    print " ok\n";
}

print "Checking for Jcode...............";
eval {
    require Jcode;
    Jcode->VERSION(0.79);
};
if ($@) {
    print " failed\n";
    $missing_modules++;
    print <<EOT;
$@
The Jcode module must be installed.

EOT
    sleep(2);  # Don't hurry too much
} else {
    print " ok\n";
}

print "Checking for GnuPG::Interface....";
eval {
    require GnuPG::Interface;
    GnuPG::Interface->VERSION(0.33);
};
if ($@) {
    print " failed\n";
    $missing_modules++;
    print <<EOT;
$@
The GnuPG module must be installed.

EOT
    sleep(2);  # Don't hurry too much
} else {
    print " ok\n";
}

print "Checking for Mail::Address.......";
eval {
    require Mail::Address;
    Mail::Address->VERSION(1.60);
};
if ($@) {
    print " failed\n";
    $missing_modules++;
    print <<EOT;
$@
The Mail::Address module must be installed.

EOT
    sleep(2);  # Don't hurry too much
} else {
    print " ok\n";
}

print "Checking for Mail::Mailer........";
eval {
    require Mail::Mailer;
    Mail::Mailer->VERSION(1.60);
};
if ($@) {
    print " failed\n";
    $missing_modules++;
    print <<EOT;
$@
The Mail::Mailer module must be installed.

EOT
    sleep(2);  # Don't hurry too much
} else {
    print " ok\n";
}

print <<EOT if $missing_modules;
The missing modules can be obtained from CPAN.  Visit
<URL:http://www.perl.com/CPAN/> to find a CPAN site near you.

EOT

my $flag = 0;
open(VERSION_FROM, $VERSION_FROM) or die;
while (<VERSION_FROM>){
    chomp;
    if (/(\$[\w:]*\bPREV_VERSION)\b.*=/){
	eval;
	$flag |= 0b100;
	last if $flag == 0b111;
    }
    elsif (/(\$[\w:]*\bPACKAGE)\b.*=/){
	eval;
	$flag |= 0b010;
	last if $flag == 0b111;
    }
    elsif (/(\$[\w:]*\bAUTHOR)\b.*=/){
	eval;
	$flag |= 0b001;
	last if $flag == 0b111;
    }
}
close VERSION_FROM;

WriteMakefile(
	      NAME    => $PACKAGE,
	      EXE_FILES => \@scripts,
	      AUTHOR => $AUTHOR,
	      VERSION_FROM => $VERSION_FROM,
	      PREREQ_PM => {
		  'Config::IniFiles' => '2.27',
		  'Jcode' => '0.79',
		  'GnuPG::Interface' => '0.33',
		  'Mail::Address' => '1.60',
		  'Mail::Mailer' => '1.60',
	      },
	      dist => { COMPRESS => 'bzip2 -f', SUFFIX => 'bz2', },
	      macro => {SVNROOT => $ENV{SVNROOT},
		    PREV_VERSION => $PREV_VERSION},
	      );

sub MY::dist_ci
{
    q!
## ν֤Distribution롣
## svn diff
## svn status
## make distcheck
## make ci
## make
## make patch
## make tag
## sudo make install-strip

ci: svn-commit svn2cl

svn-commit:
	svn commit -F log.txt

svn2cl:
	svn update
	svn log -v >ChangeLog

tag:
	svn copy $(SVNROOT)/trunk/$(NAME) $(SVNROOT)/tags/$(NAME)/$(VERSION) \
	    -m "add tag $(VERSION) to $(NAME)"
    
diff:
	svn diff --old $(SVNROOT)/tags/$(NAME)/$(VERSION) --new .
diff-prev:
	svn diff --old $(SVNROOT)/tags/$(NAME)/$(PREV_VERSION) --new .

patch: dist
	tar --extract --use-compress-program=bzip2 \
	    --file $(DISTNAME)-$(VERSION).tar.bz2 \
	&& tar --extract --use-compress-program=bzip2 \
	    --file $(DISTNAME)-$(PREV_VERSION).tar.bz2 \
	&& diff --unified --recursive --new-file $(DISTNAME)-$(PREV_VERSION) \
	    $(DISTNAME)-$(VERSION) | gpg --clearsign --not-dash-escaped \
	    | bzip2 >$(DISTNAME)-$(PREV_VERSION)-$(VERSION).patch.bz2 \
	&& rm --recursive --force $(DISTNAME)-$(PREV_VERSION) \
	    $(DISTNAME)-$(VERSION)
!;
}
